## This code creates the INPC Rx extract for the ADHD project.
#----------------------------------------------------------------------
# Install and load packages.

if (!require("pacman")) {
  install.packages("pacman")
  library(pacman)
}

p_load(data.table, collapse, ggplot2, fixest, stringr,xlsx)
#----------------------------------------------------------------------
rm(list = ls())
setwd("/N/project/optum_freedman/INPC")


##----------------- Import list of NDC codes

rm(list=ls())
ndc_list <- read.xlsx("N/project/optum_freedman/adhd_replication/inpc/intermediate/ndc_adhd.xlsx",1)
ndc_list <- as.character(ndc_list[,1])

##----------------- Exposed Cohort 2019-2021

# 1) Open the demo data
demo = fread("../../../project/INPCC19Data/release_2022_02_12/csv/demo_1.csv")
demo2 = fread("../../../project/INPCC19Data/release_2022_02_12/csv/demo_2.csv")
demo = rbind(demo,demo2)
rm(demo2)

# Remove duplicates from the demographics file
demo = funique.data.frame(demo, cols = "STUDY_ID")

# Keep children ages 5-18
demo[, age := lubridate::time_length(difftime("2020-12-31",DOB_PARSED),"years")]
demo <-subset(demo,age >= 5 & age <= 18)
demo$age = round(demo$age)

# 2) Read in the pharmacy file
ph1 = fread("../../../project/INPCC19Data/release_2022_02_12/csv/pharmacy_1.csv")
ph2 = fread("../../../project/INPCC19Data/release_2022_02_12/csv/pharmacy_2.csv")
phm = rbind(ph1,ph2)
rm(ph1,ph2)

# Limit to Rx with fill dates between Feb 2019 and Feb 2021
phm = phm[FILL_DATE_PARSED >= as.IDate("2019-02-01") &
            FILL_DATE_PARSED <= as.IDate("2021-02-28")]

# Fix NDC codes
phm$ndcnum = as.numeric(phm$NDC_CODE)
phm$length = nchar(phm$ndcnum)

phm$ndc = ifelse(phm$length==7,paste0("0000",phm$ndcnum),phm$ndcnum)
phm$ndc = ifelse(phm$length==8,paste0("000",phm$ndcnum),phm$ndc)
phm$ndc = ifelse(phm$length==9,paste0("00",phm$ndcnum),phm$ndc)
phm$ndc = ifelse(phm$length==10,paste0("0",phm$ndcnum),phm$ndc)

# Keep ADHD NDC codes
phm = phm[substring(ndc,1,9) %in% ndc_list,]

# Merge with demo file
demo <- merge(x = demo, y = phm, by = c("STUDY_ID"))
demo <- subset(demo, select = -c(ndcnum,length))

# Export dataset
fwrite(demo, file = "Extracts/exposed_Rx1921_inpc.csv")
rm(phm,demo)
gc()


##----------------- Unexposed Cohort 2018-2020

# 1) Open the demo data
demo = fread("../../../project/INPCC19Data/release_2022_02_12/csv/demo_1.csv")
demo2 = fread("../../../project/INPCC19Data/release_2022_02_12/csv/demo_2.csv")
demo = rbind(demo,demo2)
rm(demo2)

# Remove duplicates from the demographics file
demo = funique.data.frame(demo, cols = "STUDY_ID")

# Keep children ages 5-18
demo[, age := lubridate::time_length(difftime("2020-12-31",DOB_PARSED),"years")]
demo <-subset(demo,age >= 5 & age <= 18)
demo$age = round(demo$age)

# 2) Read in the pharmacy file
ph1 = fread("../../../project/INPCC19Data/release_2022_02_12/csv/pharmacy_1.csv")
ph2 = fread("../../../project/INPCC19Data/release_2022_02_12/csv/pharmacy_2.csv")
phm = rbind(ph1,ph2)
rm(ph1,ph2)

# Limit to Rx with fill dates between Feb 2018 and Feb 2020
phm = phm[FILL_DATE_PARSED >= as.IDate("2018-02-01") &
            FILL_DATE_PARSED <= as.IDate("2020-02-28")]

# Fix NDC codes
phm$ndcnum = as.numeric(phm$NDC_CODE)
phm$length = nchar(phm$ndcnum)

phm$ndc = ifelse(phm$length==7,paste0("0000",phm$ndcnum),phm$ndcnum)
phm$ndc = ifelse(phm$length==8,paste0("000",phm$ndcnum),phm$ndc)
phm$ndc = ifelse(phm$length==9,paste0("00",phm$ndcnum),phm$ndc)
phm$ndc = ifelse(phm$length==10,paste0("0",phm$ndcnum),phm$ndc)

# Keep ADHD NDC codes
phm = phm[substring(ndc,1,9) %in% ndc_list,]

# Merge with demo file
demo <- merge(x = demo, y = phm, by = c("STUDY_ID"))
demo <- subset(demo, select = -c(ndcnum,length))

# Export dataset
fwrite(demo, file = "Extracts/unexposed_Rx1820_inpc.csv")
rm(phm,demo)