
clear
set more off, perm


/**** Unexposed Cohort*****/
import delimited "$input/cohort_1820_unexposed_inpc.csv", encoding(ISO-8859-1) clear

gen male = gender =="M"

*rename variables to be consistent with optum based code
gen birthdate = date(dob, "DM20Y")
format birthdate %td
gen yrdob = year(birthdate)

rename race race_orig

gen race = "A" if race_orig == "ASIAN/PACIFIC ISLANDER"
replace race = "B" if race_orig == "BLACK OR AFRICAN AMERICAN" & ethnicity=="NOT HISPANIC OR LATINO"
replace race = "W" if race_orig == "WHITE" & ethnicity=="NOT HISPANIC OR LATINO"
replace race = "H" if ethnicity == "HISPANIC OR LATINO" & race == ""
replace race = "U" if race == ""

gen state = "IN"

merge m:1 study_id using "$input/unexposed_hi1820_inpc", assert(match master)

gen insurance_missing = _merge == 1

rename study_id patid

*drop unnecesary variables, since this is going to get very large when expanded to panel
keep patid yrdob birthdate male state race zip census_tract insurance_missing medicaid medicare selfpay govt private

*creat monthly panel structure to evenutally merge in diagnoses by month
gen yrmo = ym(2018, 2)
format yrmo %tm
xtset patid yrmo, monthly
tsappend, add(25)
foreach var of varlist yrdob birthdate state male race zip census_tract insurance_missing medicaid medicare selfpay govt private {
by patid: replace `var' = `var'[1]
}

save "$intermediate/cohort1_prepped_for_diagmerge", replace

//Create monthly diagnosis data to merge back to panels.  
import delimited "$input/unexposed_diag1820_inpc.csv", encoding(ISO-8859-1) clear
gen diagdate = date(admit_time, "DM20Y")
gen yrmo = mofd(diagdate)
format yrmo %tm

*create ADHD indictor (1 for every row in this dataset) 
gen adhd = dx_icd != ""
rename study_id patid
rename dx_icd diag

*first ADHD diagnosis 
sort patid diagdate
by patid: gen firstdiag = _n==1

*ADHD diagnosis type
gen inat = diag == "F900" 
gen hyper = diag == "F901" 
gen comb = diag == "F902" 
gen anyhyper = diag == "F901" | diag == "F902"
gen other = diag == "F908" | diag == "F909"
*ADHD diagnosis type for first diagnosis
gen inat_first = inat==1 & firstdiag == 1
gen hyper_first = hyper==1 & firstdiag == 1
gen comb_first = comb==1 & firstdiag == 1
gen anyhyper_first = anyhyper==1 & firstdiag==1
gen other_first = other==1 & firstdiag==1

*collapse to patient month level, taking max of each indicator in month
collapse (max) adhd *_first, by(patid yrmo)
save "$intermediate/cohort1_adhd", replace

//Create monthly RX data to merge back to panels.  
import delimited "$input/unexposed_Rx1820_inpc.csv", encoding(ISO-8859-1) clear
gen rxdate = date(fill_date, "DM20Y")
gen yrmo = mofd(rxdate)
format yrmo %tm
gen rx = 1
rename study_id patid
collapse (max) rx, by(patid yrmo)
save "$intermediate/cohort1_rx", replace    


//Prep Child well visits by tract and month 
import delimited "$input/unexposed_wellchild1820_inpc.csv", encoding(ISO-8859-1) clear
gen welldate = date(admit_time, "DM20Y")
gen yrmo = mofd(welldate)
format yrmo %tm
gen well_child_visit = 1
collapse (sum) well_child_visit, by(census_tract yrmo)
drop if census_tract == .
save "$intermediate/childwell_numerator1", replace


import delimited "$input/cohort_1820_unexposed_inpc.csv", encoding(ISO-8859-1) clear
*Generate census tract denominator - number of children in cohort who live in census tract
collapse (count) num_children = study_id, by(census_tract)
drop if census_tract == .
gen yrmo = ym(2018, 2)
format yrmo %tm
xtset census_tract yrmo, monthly
tsappend, add(25)
by census_tract: replace num_children = num_children[1]

merge 1:1 census_tract yrmo using "$intermediate/childwell_numerator1"

replace well_child_visit = 0 if well_child_visit == .

*create rate of e&m visits
replace well_child_visit = well_child_visit/num_children

*create cumulative e&m visits per adult_denominator1
sort census_tract yrmo
gen well_child_visit_cum = well_child_visit
by census_tract: replace well_child_visit_cum = well_child_visit_cum[_n-1] + well_child_visit if _n>1
keep census_tract yrmo well_child_visit well_child_visit_cum num_children
save "$intermediate/cohort1_well", replace


//Prep Adult E&M visits by tract and month 
//Create monthly adult E&M visits by state
import delimited "$input/unexposed_cpteval1820_adults_inpc.csv", encoding(ISO-8859-1) clear
gen welldate = date(admit_time, "DM20Y")
gen yrmo = mofd(welldate)
format yrmo %tm
gen eval = 1
collapse (sum) eval, by(census_tract yrmo)
drop if census_tract == .
save "$intermediate/adultwell_numerator1", replace

import delimited "$input/cohort_adults_1820_unexposed_inpc.csv", encoding(ISO-8859-1) clear
*Generate census tract denominator - number of adults in cohort who live in census tract
collapse (count) num_adults = study_id, by(census_tract)
drop if census_tract == .
gen yrmo = ym(2018, 2)
format yrmo %tm
xtset census_tract yrmo, monthly
tsappend, add(25)
by census_tract: replace num_adults = num_adults[1]
merge 1:1 census_tract yrmo using "$intermediate/adultwell_numerator1"
replace eval = 0 if eval == .

*create rate of e&m visits
gen eval_rate = eval/num_adults

*create cumulative e&m visits per adult_denominator1
sort census_tract yrmo
gen eval_rate_cum = eval_rate
by census_tract: replace eval_rate_cum = eval_rate_cum[_n-1] + eval_rate if _n>1
keep census_tract yrmo eval_rate eval_rate_cum num_adults
save "$intermediate/adults1_eval", replace



//Merge Dianoses and Rxs to panel
use "$intermediate/cohort1_prepped_for_diagmerge", clear
merge 1:1 patid yrmo using "$intermediate/cohort1_adhd", keep(match master)
foreach var of varlist adhd *_first { 
replace `var'=0 if `var'==.
}
drop _merge

merge 1:1 patid yrmo using "$intermediate/cohort1_rx", keep(match master)
replace rx = 0 if rx == .
drop _merge

//Merge census tract by month well visits

merge m:1 census_tract yrmo using "$intermediate/cohort1_well", keep(match master)
drop _merge

merge m:1 census_tract yrmo using "$intermediate/adults1_eval", keep(match master)
drop _merge

//Generate grades based on birth date
gen grade = 0 if birthdate > date("8/1/2012", "MDY") & birthdate <= date("8/1/2013", "MDY") 
replace grade = 1 if birthdate > date("8/1/2011", "MDY") & birthdate <= date("8/1/2012", "MDY") 
replace grade = 2 if birthdate > date("8/1/2010", "MDY") & birthdate <= date("8/1/2011", "MDY") 
replace grade = 3 if birthdate > date("8/1/2009", "MDY") & birthdate <= date("8/1/2010", "MDY") 
replace grade = 4 if birthdate > date("8/1/2008", "MDY") & birthdate <= date("8/1/2009", "MDY") 
replace grade = 5 if birthdate > date("8/1/2007", "MDY") & birthdate <= date("8/1/2008", "MDY") 
//keep elementary school age children
keep if grade >=0 & grade <=5

//Save Unexposed Cohort
save "$intermediate/cohort1_merged", replace 




/**** Exposed Cohort ****/
import delimited "$input/cohort_1921_exposed_inpc.csv", encoding(ISO-8859-1) clear

gen male = gender =="M"

*rename variables to be consistent with optum based code
gen birthdate = date(dob, "DM20Y")
format birthdate %td
gen yrdob = year(birthdate)

rename race race_orig

gen race = "A" if race_orig == "ASIAN/PACIFIC ISLANDER"
replace race = "B" if race_orig == "BLACK OR AFRICAN AMERICAN" & ethnicity=="NOT HISPANIC OR LATINO"
replace race = "W" if race_orig == "WHITE" & ethnicity=="NOT HISPANIC OR LATINO"
replace race = "H" if ethnicity == "HISPANIC OR LATINO" & race == ""
replace race = "U" if race == ""

gen state = "IN"

merge m:1 study_id using "$input/exposed_hi1921_inpc", assert(match master)

gen insurance_missing = _merge == 1

rename study_id patid

*drop unnecesary variables, since this is going to get very large when expanded to panel
keep patid yrdob birthdate male state race zip census_tract insurance_missing medicaid medicare selfpay govt private

*creat monthly panel structure to evenutally merge in diagnoses by month
gen yrmo = ym(2019, 2)
format yrmo %tm
xtset patid yrmo, monthly
tsappend, add(25)
foreach var of varlist yrdob birthdate state male race zip census_tract insurance_missing medicaid medicare selfpay govt private{
by patid: replace `var' = `var'[1]
}

save "$intermediate/cohort2_prepped_for_diagmerge", replace

//Create monthly diagnosis data to merge back to panels.  
import delimited "$input/exposed_diag1921_inpc.csv", encoding(ISO-8859-1) clear
gen diagdate = date(admit_time, "DM20Y")
gen yrmo = mofd(diagdate)
format yrmo %tm

*create ADHD indictor (1 for every row in this dataset) 
gen adhd = dx_icd != ""
rename study_id patid
rename dx_icd diag

*first ADHD diagnosis 
sort patid diagdate
by patid: gen firstdiag = _n==1

*ADHD diagnosis type
gen inat = diag == "F900" 
gen hyper = diag == "F901" 
gen comb = diag == "F902" 
gen anyhyper = diag == "F901" | diag == "F902"
gen other = diag == "F908" | diag == "F909"
*ADHD diagnosis type for first diagnosis
gen inat_first = inat==1 & firstdiag == 1
gen hyper_first = hyper==1 & firstdiag == 1
gen comb_first = comb==1 & firstdiag == 1
gen anyhyper_first = anyhyper==1 & firstdiag==1
gen other_first = other==1 & firstdiag==1

*collapse to patient month level, taking max of each indicator in month
collapse (max) adhd *_first, by(patid yrmo)

save "$intermediate/cohort2_adhd", replace


//Create monthly RX data to merge back to panels.  
import delimited "$input/exposed_Rx1921_inpc.csv", encoding(ISO-8859-1) clear
gen rxdate = date(fill_date, "DM20Y")
gen yrmo = mofd(rxdate)
format yrmo %tm
gen rx = 1
rename study_id patid
collapse (max) rx, by(patid yrmo)
save "$intermediate/cohort2_rx", replace  


//Prep Child well visits by tract and month 
import delimited "$input/exposed_wellchild1921_inpc.csv", encoding(ISO-8859-1) clear
gen welldate = date(admit_time, "DM20Y")
gen yrmo = mofd(welldate)
format yrmo %tm
gen well_child_visit = 1
collapse (sum) well_child_visit, by(census_tract yrmo)
drop if census_tract == .
save "$intermediate/childwell_numerator2", replace


import delimited "$input/cohort_1921_exposed_inpc.csv", encoding(ISO-8859-1) clear
*Generate census tract denominator - number of children in cohort who live in census tract
collapse (count) num_children = study_id, by(census_tract)
drop if census_tract == .
gen yrmo = ym(2019, 2)
format yrmo %tm
xtset census_tract yrmo, monthly
tsappend, add(25)
by census_tract: replace num_children = num_children[1]

merge 1:1 census_tract yrmo using "$intermediate/childwell_numerator2"

replace well_child_visit = 0 if well_child_visit == .

*create rate of e&m visits
replace well_child_visit = well_child_visit/num_children

*create cumulative e&m visits per adult_denominator1
sort census_tract yrmo
gen well_child_visit_cum = well_child_visit
by census_tract: replace well_child_visit_cum = well_child_visit_cum[_n-1] + well_child_visit if _n>1
keep census_tract yrmo well_child_visit well_child_visit_cum num_children
save "$intermediate/cohort2_well", replace


//Prep Adult E&M visits by tract and month 
//Create monthly adult E&M visits by state
import delimited "$input/exposed_cpteval1921_adults_inpc.csv", encoding(ISO-8859-1) clear
gen welldate = date(admit_time, "DM20Y")
gen yrmo = mofd(welldate)
format yrmo %tm
gen eval = 1
collapse (sum) eval, by(census_tract yrmo)
drop if census_tract == .
save "$intermediate/adultwell_numerator2", replace

import delimited "$input/cohort_adults_1921_exposed_inpc.csv", encoding(ISO-8859-1) clear
*Generate census tract denominator - number of adults in cohort who live in census tract
collapse (count) num_adults = study_id, by(census_tract)
drop if census_tract == .
gen yrmo = ym(2019, 2)
format yrmo %tm
xtset census_tract yrmo, monthly
tsappend, add(25)
by census_tract: replace num_adults = num_adults[1]
merge 1:1 census_tract yrmo using "$intermediate/adultwell_numerator2"
replace eval = 0 if eval == .

*create rate of e&m visits
gen eval_rate = eval/num_adults

*create cumulative e&m visits per adult_denominator1
sort census_tract yrmo
gen eval_rate_cum = eval_rate
by census_tract: replace eval_rate_cum = eval_rate_cum[_n-1] + eval_rate if _n>1
keep census_tract yrmo eval_rate eval_rate_cum num_adults
save "$intermediate/adults2_eval", replace



//Merge Dianoses and Rxs to panel
use "$intermediate/cohort2_prepped_for_diagmerge", clear
merge 1:1 patid yrmo using "$intermediate/cohort2_adhd", keep(match master)
foreach var of varlist adhd *_first { 
replace `var'=0 if `var'==.
}
drop _merge

merge 1:1 patid yrmo using "$intermediate/cohort2_rx", keep(match master)
replace rx = 0 if rx == .
drop _merge

//Merge census tract by month well visits

merge m:1 census_tract yrmo using "$intermediate/cohort2_well", keep(match master)
drop _merge

merge m:1 census_tract yrmo using "$intermediate/adults2_eval", keep(match master)
drop _merge

//Generate grades based on birth year
gen grade = 0 if birthdate > date("8/1/2013", "MDY") & birthdate <= date("8/1/2014", "MDY") 
replace grade = 1 if birthdate > date("8/1/2012", "MDY") & birthdate <= date("8/1/2013", "MDY") 
replace grade = 2 if birthdate > date("8/1/2011", "MDY") & birthdate <= date("8/1/2012", "MDY") 
replace grade = 3 if birthdate > date("8/1/2010", "MDY") & birthdate <= date("8/1/2011", "MDY") 
replace grade = 4 if birthdate > date("8/1/2009", "MDY") & birthdate <= date("8/1/2010", "MDY") 
replace grade = 5 if birthdate > date("8/1/2008", "MDY") & birthdate <= date("8/1/2009", "MDY") 
//keep elementary school age children
keep if grade >=0 & grade <=5

save "$intermediate/cohort2_merged", replace 

/*****Append the 2 cohorts, and compelete data cleaning*****/ 
use "$intermediate/cohort1_merged", clear 
gen cohort = 1
append using "$intermediate/cohort2_merged"
replace cohort = 2 if cohort == .

*post pandemic dummy - after Mar of second year for each cohort
gen post = cohort==2 & yrmo>=ym(2020,3)
replace post = 1 if cohort==1 & yrmo>=ym(2019,3)

*Month in "event time"
sort cohort patid yrmo
bysort cohort patid: gen monthnum = _n
label define monthnum 1 "Feb" 2 "Mar" 3 "Apr" 4 "May" 5 "Jun" 6 "Jul" 7 "Aug" 8 "Sep" 9 "Oct" 10 "Nov" 11 "Dec" 12 "Jan" ///
13 "Feb" 14 "Mar" 15 "Apr" 16 "May" 17 "Jun" 18 "Jul" 19 "Aug" 20 "Sep" 21 "Oct" 22 "Nov" 23 "Dec" 24 "Jan" 25 "Feb" 26 "Mar" 
lab val monthnum monthnum

*Define 6 month lookback period
gen lookback = monthnum <=6

*any adhd in lookback period
by cohort patid: egen anyadhd_lba = max(adhd) if lookback==1
by cohort patid: egen anyadhd_lb = max(anyadhd_lba)
drop anyadhd_lba

*any rx in lookback period
by cohort patid: egen anyrx_lba = max(rx) if lookback==1
by cohort patid: egen anyrx_lb = max(anyrx_lba)
drop anyrx_lba


*new adhd diagnoses or rx
gen adhd_new = adhd==1 & anyadhd_lb==0
gen rx_new = rx==1 & anyrx_lb==0


*first time new diagnosis or rx occurs
gen monthnewadhd = monthnum if adhd_new==1
by cohort patid: egen firstmonth_newadhd = min(monthnewadhd)
gen adhd_new_first = firstmonth_newadhd == monthnewadhd if monthnewadhd!=.
replace adhd_new_first = 0 if adhd_new_first==.

gen monthnewrx = monthnum if rx_new==1
by cohort patid: egen firstmonth_newrx = min(monthnewrx)
gen rx_new_first = firstmonth_newrx == monthnewrx if monthnewrx!=.
replace rx_new_first = 0 if rx_new_first==.

*Cumulative measure of first diagnosis. Once it turns on, it stays ones
gen adhd_new_cum = adhd_new_first
by cohort patid: replace adhd_new_cum = 1 if adhd_new_cum[_n-1]==1
gen rx_new_cum = rx_new_first
by cohort patid: replace rx_new_cum = 1 if rx_new_cum[_n-1]==1

*Separate cumulative new diagnoses into types: inatentive, anyhyper (hyper or combined), other
by cohort patid: egen inat_firstm = max(inat_first) 
by cohort patid: egen anyhyper_firstm = max(anyhyper_first)
by cohort patid: egen other_firstm = max(other_first)

gen inat_first_cum = adhd_new_cum == 1 & inat_firstm == 1  
gen anyhyper_first_cum = adhd_new_cum == 1 & anyhyper_firstm == 1
gen other_first_cum = adhd_new_cum == 1 & other_firstm == 1

format patid %18.0f

*have an extra month we don't want
drop if monthnum == 26

encode race, gen(race_cat)

replace race_cat = 0 if race_cat == 4
replace race_cat = 4 if race_cat == 5

replace race_cat = 0 if race == ""

lab define race_detail 0 "Unknown" 1 "Asian" 2 "Black" 3 "Hispanic" 4 "White"
lab val race_cat race_detail
*Save individual level data set
save "$intermediate/adhd_individual", replace 


*clean geographies and merge school visit data
destring zip, gen(zip_code) force

gen missing_zip = zip_code == .
gen missing_tract = census_tract == .
gen missing_geog = missing_zip == 1 | missing_tract == 1

ta missing_zip
ta missing_tract
ta missing_zip missing_tract

*2.3% have missing zip. 10% have missing tract. Those with missing zip also have missing tract

merge m:1 zip_code census_tract using "schools/cleaned_schools/ziptract_elementary.dta", keep(match master)
ta _merge
*17.75% don't merge - 10% because of missing geography. 7.75 because we don't have geogrpahy in catchment area data. 

*calculate weighted averages of school opening measures for each geography
foreach num of numlist 1/10 {
gen mXw`num' = new_share`num'*mean_mobility`num'
gen sXw`num' = new_share`num'*sd_mobility`num'
gen m19Xw`num' = new_share`num'*mean_visits19`num'
gen m20Xw`num' = new_share`num'*mean_visits20`num'
}

egen mean_mobility_weighted = rowtotal(mXw*)
egen sd_mobility_weighted = rowtotal(sXw*)
egen visits19_weighted = rowtotal(m19Xw*)
egen visits20_weighted = rowtotal(m20Xw*)

replace mean_mobility_weighted=. if _merge == 1
replace sd_mobility_weighted = . if _merge == 1
replace visits19_weighted=. if _merge == 1
replace visits20_weighted=. if _merge == 1

save "$intermediate/adhd_individual", replace 


*collapse into cells for regressions - cohort - gender - grade level - census tract by monthnumber (event time) - year 1 adhd status.
use "$intermediate/adhd_individual", clear 
keep if lookback ==0
keep if anyadhd_lb == 0
drop _merge
merge m:1 census_tract using "$intermediate/CountyTractCrosswalk", keep(match master)

preserve
keep if cohort == 2
keep if visits19_weighted > 10 & visits19_weighted < 1000
collapse mean_mobility_weighted, by(county_fips)
drop if county_fips == .
save "$intermediate/county_mobility", replace
restore


gen white = race_cat == 4 if race_cat !=0
gen black = race_cat == 2 if race_cat !=0
gen hispanic = race_cat == 3 if race_cat !=0
gen asian = race_cat == 1 if race_cat !=0



replace medicaid = . if medicaid ==0 & private == 0
replace private = . if medicaid == 0 & private == 0



bysort cohort male county_fips grade monthnum: gen cellsize = _N

collapse adhd adhd*_new_first adhd*_new_cum *first_cum rx_new_cum well_child_visit_cum well_child_visit eval_rate_cum eval_rate cellsize white black hispanic asian medicaid private , by(cohort male county_fips monthnum grade)

merge m:1 county_fips using "$intermediate/county_mobility", keep(match master)

xtile open_group= mean_mobility_weighted [w=cellsize], nq(3)
tabstat mean_mobility_weighted , by(open_group) stats(min max)

preserve 
collapse open_group, by(county_fips)
save "$intermediate/open_groups_indiana", replace
restore

gen cohort2 = cohort==2
gen post = monthnum >= 14
gen cohort2Xpost = cohort2*post 

egen countycohort = group(county_fips cohort) 

lab define pandemic 1 "Pandemic" 
lab val cohort2Xpost pandemic

*Set up opening and stability variables
lab define open_group 1 "Low Opening" 2 "Medium Opening" 3 "High Opening"
lab val open_group open_group

save "$intermediate/adhd_cells_countygrade", replace




/*	Alternative aggregation by payer as well */


use "$intermediate/adhd_individual", clear 
keep if lookback ==0
keep if anyadhd_lb == 0
drop _merge
merge m:1 census_tract using "$intermediate/CountyTractCrosswalk", keep(match master)


gen white = race_cat == 4 if race_cat !=0
gen black = race_cat == 2 if race_cat !=0
gen hispanic = race_cat == 3 if race_cat !=0
gen asian = race_cat == 1 if race_cat !=0

replace medicaid = . if medicaid ==0 & private == 0
replace private = . if medicaid == 0 & private == 0

gen payer = "medicaid" if medicaid == 1
replace payer = "private" if private == 1
replace payer = "other" if payer == ""

bysort cohort male county_fips grade monthnum payer: gen cellsize = _N

collapse adhd adhd*_new_first adhd*_new_cum *first_cum rx_new_cum well_child_visit_cum well_child_visit eval_rate_cum eval_rate cellsize white black hispanic asian medicaid private , by(cohort male county_fips monthnum grade payer)

merge m:1 county_fips using "$intermediate/open_groups_indiana", keep(match master)

gen cohort2 = cohort==2
gen post = monthnum >= 14
gen cohort2Xpost = cohort2*post 

egen countycohort = group(county_fips cohort) 

lab define pandemic 1 "Pandemic" 
lab val cohort2Xpost pandemic

*Set up opening and stability variables
lab define open_group 1 "Low Opening" 2 "Medium Opening" 3 "High Opening"
lab val open_group open_group

save "$intermediate/adhd_cells_countygrade_payer", replace

