use "$intermediate/adhd_cells_countygrade_payer", clear

*set up event study variables
gen exp = monthnum-14 if cohort==2

recode exp (.=-1)

char exp[omit] -1

xi i.exp, pref(_T)

*By Payer
capture program drop estudybypayer
**************
program define estudybypayer
**************  
syntax , title(string) depvar(varlist) absorbvars(string) [weight(string)] [controls(varlist)] [controls2(varlist)]

gen privatepay = payer == "private" 
gen medicaidpay = payer == "medicaid" 
*gen otherpay = payer == "other" 

foreach num of numlist 1/6 8/19  {
gen _TLC_`num' = _Texp_`num'*privatepay
gen _TMC_`num' = _Texp_`num'*medicaidpay
*gen _THC_`num' = _Texp_`num'*otherpay
}

capture mat drop _all
mat month = -7\-6\-5\-4\-3\-2\0\1\2\3\4\5\6\7\8\9\10\11\-7\-6\-5\-4\-3\-2\0\1\2\3\4\5\6\7\8\9\10\11\.\.\.\.\.\.\.\.
mat coln month = month


ppmlhdfe `depvar' _TLC* _TMC*  `controls' `controls2' `weight', absorb(`absorbvars') cluster(countycohort) eform

mat event = r(table)'
mat event = event , month 

capture drop _all
svmat event, names(col) 

replace b = b-1
replace ll = ll-1
replace ul = ul-1
gen ll_transformed = ll
gen ul_transformed = ul
replace ll = b-crit*se
replace ul = b+crit*se


gen group = 1 in 1/18
replace group = 2 in 19/36


drop if month == .

set obs 38
replace b = 0 if month == .
replace month = -1 if month == .
replace group = 1 in 37
replace group = 2 in 38


sort group month

label define eventmonth -7 "Aug" -6 "Sept" -5 "Oct" -4 "Nov" -3 "Dec" -2 "Jan" -1 "Feb" 0 "Mar" 1 "Apr" 2 "May" 3 "Jun" 4 "Jul" 5 "Aug" 6 "Sep" 7 "Oct" 8 "Nov" 9 "Dec" 10 "Jan" 11 "Feb", replace
lab val month eventmonth 

gen eventmonth = month-.1 if group==1
replace eventmonth = month+.1 if group==2

lab val eventmonth eventmonth


tw (rspike ll ul eventmonth  if group==1, lcolor(gs12)) (scatter b eventmonth if group==1, mcolor(black) msymbol(circle_hollow)) ///
(rspike ll ul eventmonth  if group==2, lcolor(gs12)) (scatter b eventmonth if group==2, mcolor(black) msymbol(diamond_hollow)), ///
yline(0) xlabel(-7(1)11, val angle(45))  xtitle(Month) title(`title') subtitle("Percent Change in Cumulative New Diagnosis Rate", position(11) span) ///
legend(order(2 "Private" 4 "Medicaid") rows(1))

**************
end
**************	


encode payer, gen(payer2)

drop if payer == "other"     

foreach m of numlist 0/1 {
preserve
keep if  male == `m'
if `m'==1 estudybypayer, title("Boys") depvar(adhd_new_cum) absorbvars(i.monthnum#i.payer2 i.cohort2#i.payer2 i.monthnum i.cohort2 i.county_fips i.grade) controls(well_child_visit_cum eval_rate_cum) controls2(white black hispanic medicaid private)  weight([w=cellsize])
if `m'==0 estudybypayer, title("Girls") depvar(adhd_new_cum) absorbvars(i.monthnum#i.payer2 i.cohort2#i.payer2 i.monthnum i.cohort2 i.county_fips i.grade) controls(well_child_visit_cum eval_rate_cum) controls2(white black hispanic medicaid private) weight([w=cellsize])
graph rename m`m', replace
restore
}


grc1leg  m1 m0, ycommon
graph export "$output/figureB8.eps", as(eps)  replace 





