## Enrollment files over time for the exposed and unexposed cohorts.

if (!require("pacman")) {
  install.packages("pacman")
  library(pacman)
}

p_load(data.table, collapse, ggplot2, fixest, dplyr, modelsummary, fastDummies,
       stringr, xlsx, haven)

rm(list = ls())
#----------------------------------------------------------------------

setwd("/N/project/optum_freedman/")

#--------- 1) Open continuous enrollment dataset

exp <-fread("/N/project/optum/data/raw/dodr/dod_mbr_co_enroll_r.txt.gz", 
            sep="|", header =TRUE, select =c("PATID","YRDOB","ELIGEFF","ELIGEND","GDR_CD"))
# Keep eligible patients by enrollment date
exp <- subset(exp,ELIGEFF<="2019-02-01" & ELIGEND>="2019-02-28",select=PATID:GDR_CD)
# Keep sample of children between 5-18 years old
exp <-subset(exp,YRDOB>=2002 & YRDOB<=2015)
exp = funique.data.frame(exp, cols =c('PATID'))
exp = subset(exp,select = -c(ELIGEFF,ELIGEND))
exp[, cohort := 2]
exp[, feb := 1]


unexp <-fread("/N/project/optum/data/raw/dodr/dod_mbr_co_enroll_r.txt.gz", 
              sep="|", header =TRUE, select =c("PATID","YRDOB","ELIGEFF","ELIGEND","GDR_CD"))
# Keep eligible patients by enrollment date
unexp <- subset(unexp,ELIGEFF<="2018-02-01" & ELIGEND>="2018-02-28",select=PATID:GDR_CD)
# Keep sample of children between 5-18 years old
unexp <-subset(unexp,YRDOB>=2002 & YRDOB<=2015)
unexp = funique.data.frame(unexp, cols =c('PATID'))
unexp = subset(unexp,select = -c(ELIGEFF,ELIGEND))
unexp[, cohort := 1]
unexp[, feb := 1]


#--------- 2) Merge to enrollment tables to create time series

enroll = fread("/N/project/optum/data/raw/dodr/dod_mbr_co_enroll_r.txt.gz", 
               sep="|", header =TRUE, select =c("PATID","ELIGEFF","ELIGEND"))

exp = merge(enroll,exp,by="PATID")
exp = subset(exp, ELIGEND>="2019-02-01")

unexp = merge(enroll,unexp,by="PATID")
unexp = subset(unexp, ELIGEND>="2018-02-01")

cohort = rbind(unexp,exp)
fwrite(cohort, file = "Extracts/DOD/enrollment_cohorts_feb.csv")
rm(list=ls())