# Optum DOD - ICD-10 Mental Health codes (F diagnosis)
# Individuals from 5 to 18 years old

library(arrow)
library(data.table)
library(fs)
library(plyr)
library(dplyr)
library(stringr)
library(xlsx)
library(haven)
library(zoo)
library("rio")

#-------- Exposed Cohort 2019-2021 --------#

rm(list=ls())
quart <- list("2019q1","2019q2","2019q3","2019q4","2020q1",
              "2020q2","2020q3","2020q4","2021q1")

for (i in quart) {
  
  # Open diagnosis table
  assign(paste0("diag_diag",i), fread(paste0("/N/project/optum/data/raw/dodr/dod_diag",i,".txt.gz"), sep="|", header =TRUE, select =c("PATID", "DIAG", "ICD_FLAG", "FST_DT", "PAT_PLANID", "DIAG_POSITION","CLMID","LOC_CD")))
  
  # Keep only Mental Health codes (start with F)
  get(paste0("diag_diag",i))[, sub_code :=  substring(DIAG,1,1)]
  assign(paste0("diag_diag",i), get(paste0("diag_diag",i))[sub_code == "F"])

}

# Append datasets by quarter
diag1921 <- rbind(diag_diag2019q1,diag_diag2019q2,diag_diag2019q3,diag_diag2019q4,diag_diag2020q1,
                  diag_diag2020q2,diag_diag2020q3,diag_diag2020q4,diag_diag2021q1)
rm(diag_diag2019q1,diag_diag2019q2,diag_diag2019q3,diag_diag2019q4,diag_diag2020q1,
   diag_diag2020q2,diag_diag2020q3,diag_diag2020q4,diag_diag2021q1)

# Member continuous enrollment
members_co <-fread("/N/project/optum/data/raw/dodr/dod_mbr_co_enroll_r.txt.gz", 
                   sep="|", header =TRUE, select =c("PATID","PAT_PLANID","YRDOB","ELIGEFF","ELIGEND","GDR_CD"))
# Keep eligible patients by enrollment date
members_co <- subset(members_co,ELIGEFF<="2019-02-01" & ELIGEND>="2021-03-31",select=PATID:GDR_CD)
# Keep sample of children between 5-18 years old
members_co <-subset(members_co,YRDOB>=2002 & YRDOB<=2015)

merged1921 <-merge(diag1921,members_co, by="PATID")

## Export file
export(merged1921,"/N/project/optum_freedman/Extracts/DOD/exposed_MentalHealth1921_dod.csv")
rm(list=ls())
gc()


#-------- Unexposed Cohort 2018-2020 --------#

quart <-list("2018q1","2018q2","2018q3","2018q4","2019q1",
             "2019q2","2019q3","2019q4","2020q1")

for (i in quart) {
  
  # Open diagnosis table
  assign(paste0("diag_diag",i), fread(paste0("/N/project/optum/data/raw/dodr/dod_diag",i,".txt.gz"), sep="|", header =TRUE, select =c("PATID", "DIAG", "ICD_FLAG", "FST_DT", "PAT_PLANID", "DIAG_POSITION","CLMID","LOC_CD")))
  
  # Keep only Mental Health codes (start with F)
  get(paste0("diag_diag",i))[, sub_code :=  substring(DIAG,1,1)]
  assign(paste0("diag_diag",i), get(paste0("diag_diag",i))[sub_code == "F"])

}

# Append datasets by quarter
diag1820 <- rbind(diag_diag2018q1,diag_diag2018q2,diag_diag2018q3,diag_diag2018q4,diag_diag2019q1,
                  diag_diag2019q2,diag_diag2019q3,diag_diag2019q4,diag_diag2020q1)
rm(diag_diag2018q1,diag_diag2018q2,diag_diag2018q3,diag_diag2018q4,diag_diag2019q1,
   diag_diag2019q2,diag_diag2019q3,diag_diag2019q4,diag_diag2020q1)

# Member continuous enrollment
members_co <-fread("/N/project/optum/data/raw/dodr/dod_mbr_co_enroll_r.txt.gz", sep="|", header =TRUE, select =c("PATID", "PAT_PLANID","YRDOB","ELIGEFF","ELIGEND","GDR_CD"))
# Keep eligible patients by enrollment date
members_co <- subset(members_co,ELIGEFF<="2018-02-01" & ELIGEND>="2020-03-31",select=PATID:GDR_CD)
# Keep sample of children between 5-18 years old
members_co <-subset(members_co,YRDOB>=2002 & YRDOB<=2015)

merged1820 <-merge(diag1820,members_co, by="PATID")

## Export file
export(merged1820,"/N/project/optum_freedman/Extracts/DOD/unexposed_MentalHealth1820_dod.csv")
rm(list=ls())
gc()