# Optum DOD - Rx Extracts
# Individuals from 5 to 18 years old

library(arrow)
library(data.table)
library(fs)
library(plyr)
library(dplyr)
library(stringr)
library(xlsx)
library(haven)
library("rio")

#-------- Import list of NDC codes --------#

rm(list=ls())
ndc_list <- read.xlsx("N/project/optum_freedman/adhd_replication/optum/intermediate/ndc_adhd.xlsx",1)
ndc_list <- as.character(ndc_list[,1])


#-------- Exposed Cohort 2019-2021 --------#

quart <- list("2019q1","2019q2","2019q3","2019q4","2020q1",
              "2020q2","2020q3","2020q4","2021q1")

for (i in quart) {
  
  # Open Rx table
  assign(paste0("rx",i), fread(paste0("/N/project/optum/data/raw/dodr/dod_r",i,".txt.gz"), sep="|", header =TRUE, select =c("PATID","BRND_NM","DAYS_SUP","FILL_DT","FST_FILL","GNRC_NM","NDC","PHARM","RFL_NBR","STRENGTH","PRESCRIBER_PROV")))
  # Keep only ADHD NDC codes
  assign(paste0("rx",i), get(paste0("rx",i))[substring(NDC,1,9) %in% ndc_list,])
  
  # Rename Provider variable to merge with provider bridge
  assign(paste0("rx",i), get(paste0("rx",i)) %>% rename(PROV=PRESCRIBER_PROV))
  
  # Merge Rx and Provider bridge
  assign(paste0("prov_bridge"), fread(paste0("/N/project/optum/data/raw/dodr/dod_provider_bridge",".txt.gz"), sep="|", header =TRUE, select =c("PROV","PROV_UNIQUE","NPI")))
  assign(paste0("rx",i), merge(get(paste0("rx",i)),prov_bridge, by=c("PROV"), all.x=TRUE))
  rm(prov_bridge)
  
  # Merge Rx and Provider
  assign(paste0("provider"), fread(paste0("/N/project/optum/data/raw/dodr/dod_provider",".txt.gz"), sep="|", header =TRUE, select =c("PROV_UNIQUE","GRP_PRACTICE","HOSP_AFFIL","PROV_STATE","PROV_TYPE","TAXONOMY1","TAXONOMY2")))
  assign(paste0("rx",i), merge(get(paste0("rx",i)),provider, by=c("PROV_UNIQUE"), all.x=TRUE))
  rm(provider)
}

# Append datasets by quarter
rx1921 <- rbind(rx2019q1,rx2019q2,rx2019q3,rx2019q4,rx2020q1,
                rx2020q2,rx2020q3,rx2020q4,rx2021q1)
rm(rx2019q1,rx2019q2,rx2019q3,rx2019q4,rx2020q1,
   rx2020q2,rx2020q3,rx2020q4,rx2021q1)

## Member continuous enrollment
members_co <-fread("/N/project/optum/data/raw/dodr/dod_mbr_co_enroll_r.txt.gz", sep="|", header =TRUE, select =c("PATID","YRDOB","ELIGEFF","ELIGEND","GDR_CD"))
# Keep eligible patients by enrollment date
members_co <- subset(members_co,ELIGEFF<="2019-02-01" & ELIGEND>="2021-03-31",select=PATID:GDR_CD)
# Keep sample of children between 5-18 years old
members_co <-subset(members_co,YRDOB>=2002 & YRDOB<=2015)

merged1921 <-merge(rx1921,members_co, by="PATID")

# Stimulants and non-stimulants
merged1921$stimulant <- rep(1,nrow(merged1921))
merged1921$stimulant[merged1921$NDC == "00002322730" | merged1921$NDC == "00002322830" | merged1921$NDC == "00002322930" | merged1921$NDC == "00002323830" | 
                       merged1921$NDC == "00002323930" | merged1921$NDC == "00002325030" | merged1921$NDC == "00002325130" | merged1921$NDC == "17772013190" |
                       merged1921$NDC == "17772013160" | merged1921$NDC == "17772013107" | merged1921$NDC == "17772013130" | merged1921$NDC == "17772013101" | 
                       merged1921$NDC == "17772013230" | merged1921$NDC == "17772013260" | merged1921$NDC == "17772013201" | merged1921$NDC == "17772013290" |
                       merged1921$NDC == "17772013207" | merged1921$NDC == "17772013330" | merged1921$NDC == "17772013360" | merged1921$NDC == "17772013307" | 
                       merged1921$NDC == "17772013390" | merged1921$NDC == "17772013301" | merged1921$NDC == "59212065860" | merged1921$NDC == "59212065813" |
                       merged1921$NDC == "54092051302" | merged1921$NDC == "54092051502" | merged1921$NDC == "54092051702" | merged1921$NDC == "54092051902" ] <- 0

## Export file
export(merged1921,"/N/project/optum_freedman/Extracts/DOD/exposed_rx1921_dod.csv")
rm(members_co,merged1921,quart,rx1921)


#-------- Unexposed Cohort 2018-2020 --------#

quart <-list("2018q1","2018q2","2018q3","2018q4","2019q1",
             "2019q2","2019q3","2019q4","2020q1")

for (i in quart) {
  
  # Open Rx table
  assign(paste0("rx",i), fread(paste0("/N/project/optum/data/raw/dodr/dod_r",i,".txt.gz"), sep="|", header =TRUE, select =c("PATID","BRND_NM","DAYS_SUP","FILL_DT","FST_FILL","GNRC_NM","NDC","PHARM","RFL_NBR","STRENGTH","PRESCRIBER_PROV")))
  # Keep only ADHD NDC codes
  assign(paste0("rx",i), get(paste0("rx",i))[substring(NDC,1,9) %in% ndc_list,])
  
  # Rename Provider variable to merge with provider bridge
  assign(paste0("rx",i), get(paste0("rx",i)) %>% rename(PROV=PRESCRIBER_PROV))
  
  # Merge Rx and Provider bridge
  assign(paste0("prov_bridge"), fread(paste0("/N/project/optum/data/raw/dodr/dod_provider_bridge",".txt.gz"), sep="|", header =TRUE, select =c("PROV","PROV_UNIQUE","NPI")))
  assign(paste0("rx",i), merge(get(paste0("rx",i)),prov_bridge, by=c("PROV"), all.x=TRUE))
  rm(prov_bridge)
  
  # Merge Rx and Provider
  assign(paste0("provider"), fread(paste0("/N/project/optum/data/raw/dodr/dod_provider",".txt.gz"), sep="|", header =TRUE, select =c("PROV_UNIQUE","GRP_PRACTICE","HOSP_AFFIL","PROV_STATE","PROV_TYPE","TAXONOMY1","TAXONOMY2")))
  assign(paste0("rx",i), merge(get(paste0("rx",i)),provider, by=c("PROV_UNIQUE"), all.x=TRUE))
  rm(provider)
}

# Append datasets by quarter
rx1820 <- rbind(rx2018q1,rx2018q2,rx2018q3,rx2018q4,rx2019q1,
                rx2019q2,rx2019q3,rx2019q4,rx2020q1)
rm(rx2018q1,rx2018q2,rx2018q3,rx2018q4,rx2019q1,
   rx2019q2,rx2019q3,rx2019q4,rx2020q1)

## Member continuous enrollment
members_co <-fread("/N/project/optum/data/raw/dodr/dod_mbr_co_enroll_r.txt.gz", sep="|", header =TRUE, select =c("PATID","YRDOB","ELIGEFF","ELIGEND","GDR_CD"))
# Keep eligible patients by enrollment date
members_co <- subset(members_co,ELIGEFF<="2018-02-01" & ELIGEND>="2020-03-31",select=PATID:GDR_CD)
# Keep sample of children between 5-18 years old
members_co <-subset(members_co,YRDOB>=2002 & YRDOB<=2015)

merged1820 <-merge(rx1820,members_co, by="PATID")

# Stimulants and non-stimulants
merged1820$stimulant <- rep(1,nrow(merged1820))
merged1820$stimulant[merged1820$NDC == "00002322730" | merged1820$NDC == "00002322830" | merged1820$NDC == "00002322930" | merged1820$NDC == "00002323830" | 
                       merged1820$NDC == "00002323930" | merged1820$NDC == "00002325030" | merged1820$NDC == "00002325130" | merged1820$NDC == "17772013190" |
                       merged1820$NDC == "17772013160" | merged1820$NDC == "17772013107" | merged1820$NDC == "17772013130" | merged1820$NDC == "17772013101" | 
                       merged1820$NDC == "17772013230" | merged1820$NDC == "17772013260" | merged1820$NDC == "17772013201" | merged1820$NDC == "17772013290" |
                       merged1820$NDC == "17772013207" | merged1820$NDC == "17772013330" | merged1820$NDC == "17772013360" | merged1820$NDC == "17772013307" | 
                       merged1820$NDC == "17772013390" | merged1820$NDC == "17772013301" | merged1820$NDC == "59212065860" | merged1820$NDC == "59212065813" |
                       merged1820$NDC == "54092051302" | merged1820$NDC == "54092051502" | merged1820$NDC == "54092051702" | merged1820$NDC == "54092051902" ] <- 0

## Export file
export(merged1820,"/N/project/optum_freedman/Extracts/DOD/unexposed_rx1820_dod.csv")
rm(list=ls())