use "$intermediate/adhd_cells", clear
keep if lookback==0
keep if anyadhd_lb==0

*set up event time variables with -1 as omitted time
gen exp = monthnum-14 if cohort==2
recode exp (.=-1)
char exp[omit] -1
xi i.exp, pref(_T)

capture program drop counterfactual
**************
program define counterfactual
************** 

syntax , title(string) depvar(varlist) spec(string) [weight(string)] controls(varlist) prevlabposition(real)

ppmlhdfe `depvar' _Texp* `controls' `weight', absorb(i.monthnum i.cohort2 i.statenum i.grade i.race_cat, savefe) cluster(statecohort) d

*predictions
capture drop xb xbd
predict xb, xb
egen xbd = rowtotal(xb _ppmlhdfe_d)

*Y0
capture drop y0
gen y0 = .
foreach num of numlist 1/6 8/19 {
	replace y0 = exp(xbd - _b[_Texp_`num']) if exp == `num' - 8 & cohort==2 
}
replace y0 = exp(xbd) if exp == -1 & cohort == 2

replace y0 = exp(xbd) if cohort == 1

gen ev_y = exp(xbd)

collapse adhd_new_cum ev_y y0 cellsize0 cellsize1 marquardt upper lower [w=cellsize], by(monthnum cohort)

gen eventmonth = monthnum - 14

label define eventmonth -7 "Aug" -6 "Sept" -5 "Oct" -4 "Nov" -3 "Dec" -2 "Jan" -1 "Feb" 0 "Mar" 1 "Apr" 2 "May" 3 "Jun" 4 "Jul" 5 "Aug" 6 "Sep" 7 "Oct" 8 "Nov" 9 "Dec" 10 "Jan" 11 "Feb", replace
lab val eventmonth eventmonth 

*add in previously diagnosed
gen counterfactual_total = (cellsize0*y0 + cellsize1)/(cellsize0+cellsize1)	
gen predicted_total = (cellsize0*ev_y + cellsize1)/(cellsize0+cellsize1)
gen actual_total = (cellsize0*adhd_new_cum + cellsize1)/(cellsize0+cellsize1)

*labels
gen toshow_counter = string(counterfactual_total, "%9.3f") + " Counterfactual Diagnosis Rate"
gen toshow_predict = string(predicted_total, "%9.3f") + " Predicted Diagnosis Rate"
gen toshow_actual = string(actual_total, "%9.3f" ) + " Observed Diagnosis Rate"
gen toshow_marquardt1 = string(marquardt, "%9.3f") + " Estimated True Prevalence (Marquardt 2021)"

*plot
tw (rarea upper lower eventmonth, fcolor(gs13%50) lcolor(gs13%50)) (scatter counterfactual_total eventmonth if cohort==2, ms(square) mc(black)) (scatter counterfactual_total eventmonth if cohort==2 & eventmonth==11, ms(none) mlabel(toshow_counter) mlabc(black)) ///
(scatter predicted_total eventmonth if cohort == 2, ms(circle) mc(black)) (scatter predicted_total eventmonth if cohort==2 & eventmonth==11, ms(none) mlabel(toshow_predict) mlabc(black)) ///
(line marquardt eventmonth if cohort == 2, lpattern(dash) lcolor(black)) (scatter marquardt eventmonth if cohort==2 & eventmonth==11, ms(none) mlabel(toshow_marquardt1) mlabc(black) mlabpos(`prevlabposition')) ///
, ///  
legend(off) ///
xtitle(Month) title(`title')  xline(0) xlabel(-7(1)11, val angle(45)) ylabel(0(.02).12) graphregion(margin(r+40)) 

*stats for reporting
sum y0 if cohort==2 & eventmonth == 11 
scalar y0end = r(mean)

sum ev_y if cohort==2 & eventmonth == 11
scalar ev_yend = r(mean)

sum adhd_new_cum if cohort == 2 & eventmonth == 11
scalar adhd_new_cumend = r(mean)

gen shortfall_pp = ev_y-y0 if cohort == 2
sum shortfall_pp if cohort==2 & eventmonth == 11
scalar shortfall_pp = r(mean)

nlcom (exp(_b[_Texp_19])-1) 
matrix b=r(b)
scalar shortfall_prop = b[1,1]

gen shortfall_prop_check = (ev_y/y0)-1 if cohort == 2
sum shortfall_prop_check if cohort == 2 & eventmonth == 11
scalar shortfall_prop_check = r(mean)

mat table = y0end, ev_yend, adhd_new_cumend, shortfall_pp, shortfall_prop
mat colnames table = counterfactual predicted actual shortfall_pp shortfall_prop

**************
end
**************	

*Get counts of number of kids with diangosis during look back for constructing total 
preserve
use "$intermediate/adhd_cells", clear
keep if lookback==0
keep if cohort == 2 
collapse (sum) cellsize, by(cohort anyadhd_lb male)

reshape wide cellsize, i(male) j(anyadhd_lb)
tempfile cellsize

*Marquardt and literature estimates
gen marquardt = .084 if male == 1
replace marquardt = .056 if male == 0

gen upper = .118 if male == 1
gen lower = .09 if male == 1

replace upper = .054 if male == 0
replace lower = .028 if male == 0

save `cellsize', replace
restore

merge m:1 male using `cellsize'	  


*Run for boys and girls
foreach m of numlist 0/1 {
preserve
keep if male == `m'
if `m'==1 counterfactual, title("Boys") depvar(adhd_new_cum) spec(ppml) weight([w=cellsize]) controls(well_child_visit_cum eval_rate_cum) prevlabposition(6)
if `m'==0 counterfactual, title("Girls") depvar(adhd_new_cum) spec(ppml) weight([w=cellsize]) controls(well_child_visit_cum eval_rate_cum) prevlabposition(12)
graph rename m`m', replace
restore
}


graph replay m1
graph export "$output/figure9a.eps", as(eps) replace 
graph replay m0
graph export "$output/figure9b.eps", as(eps) replace 



