** Create the enrollment figures for each cohort

clear
set more off, perm
set scheme plotplainblind

*** Prepare the unexposed cohort

import delimited "$input/enrollment_cohorts_feb.csv", clear
keep if inrange(yrdob,2009,2015)     // Keep 5-11 year olds
keep if cohort == 1
gen male = gdr_cd =="M"
tempfile unexp
save `unexp'

gen eligeffdate = date(eligeff,"YMD")
format eligeffdate %td
gen eligenddate = date(eligend,"YMD")
format eligenddate %td
gen yrmo = ym(year(eligeffdate),month(eligeffdate))
format yrmo %tm

replace yrmo = ym(2018,2) if yrmo <= tm(2018m2)
keep patid eligeffdate eligenddate yrmo
tempfile cohort
save `cohort', replace

// Create monthly panel
use `unexp', clear
duplicates drop patid, force
local totenroll = _N
gen yrmo = ym(2018, 2)
format yrmo %tm
xtset patid yrmo, monthly
tsappend, add(25)
foreach var of varlist yrdob male cohort feb {
   by patid: replace `var' = `var'[1]
}
drop eligeff eligend gdr_cd

merge m:1 patid yrmo using `cohort', nogen keep(1 3)

foreach var in eligeffdate eligenddate {
   replace `var' =  `var'[_n-1] if `var' == . & `var'[_n-1]!=. & patid == patid[_n-1]
}

preserve
   sort patid eligeffdate
   duplicates drop patid, force
   ren (eligeffdate eligenddate) (eligeffdate1 eligenddate1)
   keep patid eligeffdate1 eligenddate1
   tempfile date1
   save `date1', replace
restore
merge m:1 patid using `date1', nogen keep(1 3)

// Enrollment variable
gen enrolled = inrange(yrmo,ym(year(eligeffdate),month(eligeffdate)),ym(year(eligenddate),month(eligenddate)))

collapse (sum) enrolled, by(yrmo)
gen rate = enrolled/`totenroll'
gen cohort = 1
tempfile aux
save `aux'


*** Prepare the exposed cohort

import delimited "$input/enrollment_cohorts_feb.csv", clear
keep if inrange(yrdob,2009,2015)     // Keep 5-11 year olds
keep if cohort == 2
gen male = gdr_cd =="M"
tempfile exp
save `exp'

gen eligeffdate = date(eligeff,"YMD")
format eligeffdate %td
gen eligenddate = date(eligend,"YMD")
format eligenddate %td
gen yrmo = ym(year(eligeffdate),month(eligeffdate))
format yrmo %tm

replace yrmo = ym(2019,2) if yrmo <= tm(2019m2)
keep patid eligeffdate eligenddate yrmo
tempfile cohort
save `cohort', replace

// Create monthly panel
use `exp', clear
duplicates drop patid, force
local totenroll = _N
gen yrmo = ym(2019, 2)
format yrmo %tm
xtset patid yrmo, monthly
tsappend, add(25)
foreach var of varlist yrdob male cohort feb {
   by patid: replace `var' = `var'[1]
}
drop eligeff eligend gdr_cd

merge m:1 patid yrmo using `cohort', nogen keep(1 3)

foreach var in eligeffdate eligenddate {
   replace `var' =  `var'[_n-1] if `var' == . & `var'[_n-1]!=. & patid == patid[_n-1]
}

preserve
   sort patid eligeffdate
   duplicates drop patid, force
   ren (eligeffdate eligenddate) (eligeffdate1 eligenddate1)
   keep patid eligeffdate1 eligenddate1
   tempfile date1
   save `date1', replace
restore
merge m:1 patid using `date1', nogen keep(1 3)

// Enrollment variable
gen enrolled = inrange(yrmo,ym(year(eligeffdate),month(eligeffdate)),ym(year(eligenddate),month(eligenddate)))

collapse (sum) enrolled, by(yrmo)
gen rate = enrolled/`totenroll'
gen cohort = 2

append using `aux'
sort cohort yrmo
egen month = seq(), by(cohort)
label define month 1 "Feb" 2 "Mar" 3 "Apr" 4 "May" 5 "Jun" 6 "Jul" 7 "Aug" 8 "Sep" 9 "Oct" 10 "Nov" 11 "Dec" 12 "Jan" ///
 13 "Feb" 14 "Mar" 15 "Apr" 16 "May" 17 "Jun" 18 "Jul" 19 "Aug" 20 "Sep" 21 "Oct" 22 "Nov" 23 "Dec" 24 "Jan" 25 "Feb" 26 "Mar" 
lab val month month

*** Plot

# delimit;
twoway (connected rate month if cohort == 1, mcolor(black) msymbol(circle) msize(vsmall) lcolor(black) lpattern(solid))
       (connected rate month if cohort == 2, mcolor(vermillion) msymbol(circle) msize(vsmall) lcolor(vermillion) lpatter(dash))
       (pci 0.721 12.2 0.78 13.5, color(black))
       (pci 0.69 11.8 0.65 11, color(vermillion))
       (pci 0.54 24.1 0.60 24.7, color(black))
       (pci 0.53 23.7 0.53 22.0, color(vermillion))
       ,
       text(0.79 13.6 "January 2019", justification(left) place(e) color(black) size(small))
       text(0.64 11.5 "January 2020", justification(left) place(sw) color(vermillion) size(small))
       text(0.62 23.3 "January 2020", justification(left) place(e) color(black) size(small))
       text(0.54 22.1 "January 2021", justification(left) place(sw) color(vermillion) size(small))
       xtitle(Month) ytitle("") subtitle("Enrollment Rate", position(11) span) xlabel(1(1)26, val angle(45)) xline(14)
       legend(on order(1 "Unexposed Cohort" 2 "Exposed Cohort") rows(1) position(6))
;
# delimit cr
gr export "$output/figureB1.eps", replace
