** Create Table B1

clear
set more off, perm


// Open individual panel

use "$intermediate/adhd_individual.dta", clear

collapse (max) race_cat grade male anyadhd_lb anyrx_lb, by(patid cohort)

tab race_cat, gen(race)
ren (race1 race2 race3 race4) (asian black hispanic white)
gen female = male == 0

** Keep the no-ADHD sample in the pre-period
keep if anyadhd_lb == 0

qui tab grade
local obs = r(N)

// Format table
mat s = J(7,5,.)

local k = 1
foreach var in grade female white black asian hispanic {
   sum `var' if cohort == 1
   mat s[`k',1] = r(mean)
   ttest `var', by(cohort)
   mat s[`k',4] = abs(r(p))
   mat s[`k',5] = r(mu_2) - r(mu_1)
   local k = `k' + 1
}
local k = 1
foreach var in grade female white black asian hispanic {
   sum `var' if cohort == 2
   mat s[`k',2] = r(mean)
   local k = `k' + 1
}
clear
mat colnames s = unexposed exposed n_obs pvalue difference
svmat s, names(col)

replace n_obs = `obs'

gen var  = ""
order var
replace var = "Expected Grade" in 1
replace var = "Female" in 2
replace var = "White" in 3
replace var = "Black" in 4
replace var = "Asian" in 5
replace var = "Hispanic" in 6
replace var = "HH Income $\leq$ 74K" in 7


*** HH Income variable - Use SES files

// Unexposed cohort

preserve
   import delimited "$inputses/unexposed_diag1820_ses.csv", clear

   drop if d_race_code==""
   gen diagdate = date(fst_dt, "YMD")
   gen yrmo = mofd(diagdate)
   format yrmo %tm
   gen adhd = diag != ""

   sort patid diagdate yrmo
   drop if yrmo <= tm(2018m1)
   by patid: egen adhd_lbaux = max(adhd) if yrmo <= tm(2018m7)
   by patid: egen adhd_lb    = max(adhd_lbaux)
   drop if adhd_lb == 1

   gen keep = 1
   duplicates drop patid, force
   keep patid keep
   tempfile adhd1
   save `adhd1', replace

   import delimited "$inputses/cohort_1820_unexposed_ses.csv", clear
   keep if inrange(yrdob,2008,2013)
   merge 1:1 patid using `adhd1', nogen keep(1 3)
   drop if d_race_code==""

   * HHincome
   replace d_household_income_range_code = . if d_household_income_range_code == 0
   gen hh_inc74 = d_household_income_range_code <= 4
   replace hh_inc74 = . if d_household_income_range_code == .
   gen cohort = 1
   keep patid d_household_income_range_code hh_inc74 cohort
   order patid d_household_income_range_code hh_inc74 cohort
   tempfile unexposed_ses
   save `unexposed_ses', replace

   // Exposed cohort

   import delimited "$inputses/exposed_diag1921_ses.csv", clear

   drop if d_race_code==""
   gen diagdate = date(fst_dt, "YMD")
   gen yrmo = mofd(diagdate)
   format yrmo %tm
   gen adhd = diag != ""

   sort patid diagdate yrmo
   drop if yrmo <= tm(2019m1)
   by patid: egen adhd_lbaux = max(adhd) if yrmo <= tm(2019m7)
   by patid: egen adhd_lb    = max(adhd_lbaux)
   drop if adhd_lb == 1

   gen keep = 1
   duplicates drop patid, force
   keep patid keep
   tempfile adhd2
   save `adhd2', replace

   import delimited "$inputses/cohort_1921_exposed_ses.csv", clear
   keep if inrange(yrdob,2009,2014)
   merge 1:1 patid using `adhd2', nogen keep(1 3)
   drop if d_race_code==""

   * HHincome
   replace d_household_income_range_code = . if d_household_income_range_code == 0
   gen hh_inc74 = d_household_income_range_code <= 4
   replace hh_inc74 = . if d_household_income_range_code == .
   gen cohort = 2
   keep patid d_household_income_range_code hh_inc74 cohort
   order patid d_household_income_range_code hh_inc74 cohort
   tempfile exposed_ses
   save `exposed_ses', replace

   * Append files
   use `unexposed_ses', clear
   append using `exposed_ses'

   ttest hh_inc74, by(cohort)
   local pval = r(p)
   local diff = r(mu_2) - r(mu_1)

   sum hh_inc74 if cohort == 1
   local mean1 = r(mean)
   sum hh_inc74 if cohort == 2
   local mean2 = r(mean)
   qui tab hh_inc74
   local incobs = r(N)
restore

replace unexposed = `mean1' in 7
replace exposed = `mean2' in 7
replace n_obs = `incobs' in 7
replace pvalue = `pval' in 7
replace difference = `diff' in 7

foreach var in exposed unexposed pvalue {
   format `var' %5.3f
}
tostring difference, replace format("%6.5f") force
gen diff = ""
replace diff = difference + "***" if pvalue <= 0.01
replace diff = difference + "**" if pvalue <= 0.05 & diff == ""
replace diff = difference + "*" if pvalue <= 0.1 & diff == ""
replace diff = difference if diff == ""

drop n_obs pvalue difference
ren diff difference

// Format table
forvalues i = 1/3 {
      gen c`i' = "&"
   }
   gen c4 = "\\"
   order var c1 unexposed c2 exposed c3 difference c4
   forvalues i = 1/4 {
   label var c`i' ""
}
replace c4 = "" in 7
outsheet var-c4 using "$output/tableB1.tex", replace noquote nonames delimit(" ")
