#input: open_groups_states.dta, open_groups_indiana.dta
#output: figure-4a.pdf, figure-4b.pdf


rm(list = ls())
library(haven) 
library(tigris) 
library(dplyr) 
library(ggplot2) 

options(tigris_class = "sf")
options(tigris_use_cache = TRUE)


########################################################
#Step 1: read in state-OpenGroup data 
open_groupings_st=read_dta('../../Optum/intermediate/open_groups_states.dta')


open_groupings_st=open_groupings_st%>%
  filter(!is.na(open_group))%>%
  mutate(group=
           case_when(open_group==1 ~ "Low",
                     open_group==3 ~ "High",
                     T ~ "Medium"))

open_groupings_st$group=factor(open_groupings_st$group, levels=c("Low","Medium","High"))

####################################
#Step 2: read in map shape files 
map_shape=states(cb=TRUE)%>%shift_geometry()
map_shape=map_shape%>%
  select(GEOID,STUSPS,geometry)%>%
  rename(state=STUSPS)


#######################
#Step 3: Make map 

group.colors <- c(Low = "#636363", Medium = "#bdbdbd", High ="#f0f0f0")
group_map=open_groupings_st%>%
  left_join(map_shape,by="state") %>%
  ggplot(aes(geometry=geometry, fill=group))+
  geom_sf()+
  coord_sf(crs = 26915) +
  scale_fill_manual(values=group.colors)+
  theme_void()+
  theme(panel.grid.major = element_line(colour = 'transparent'))+
  theme(legend.position = "bottom")+
  labs(caption="State Openness Group", fill="", color="")+
  theme(plot.caption = element_text(size=15, hjust = 0.5))

group_map+  theme(legend.key.size = unit(1, 'cm'), 
                  legend.key.height = unit(1, 'cm'), 
                  legend.key.width = unit(1, 'cm'),
                  legend.title = element_text(size=15),
                  legend.text = element_text(size=15)) 

dev.copy(pdf,'figure-4a.pdf')
dev.off()

##################################################
##################################################
#Indiana county group map 

#######################
#Step 1:read in Indiana countyfips-opengroup data 

open_groupings_in=read_dta('../../INPC/intermediate/open_groups_indiana.dta')

open_groupings_in=open_groupings_in%>%
  filter(!is.na(open_group))%>%
  mutate(group=
           case_when(open_group==1 ~ "Low",
                     open_group==3 ~ "High",
                     T ~ "Medium"))
open_groupings_in$group=factor(open_groupings_in$group, levels=c("Low","Medium","High"))

#######################
#Step 2: read in Indiana county shape files and merge

in_county=counties(state="IN", cb=T)
in_county=in_county%>%
  select(COUNTYFP,geometry)%>%
  mutate(county_fips=as.double(COUNTYFP))

open_groupings_in=open_groupings_in%>%
  left_join(in_county, by="county_fips")



#######################
#Step 3: Make map 
group.colors <- c(Low = "#636363", Medium = "#bdbdbd", High ="#f0f0f0")
group_map_in=open_groupings_in%>%
  ggplot(aes(geometry=geometry, fill=group))+
  geom_sf()+
  coord_sf(crs = 26915) +
  scale_fill_manual(values=group.colors)+
  theme_void()+
  theme(panel.grid.major = element_line(colour = 'transparent'))+
  theme(legend.position = "bottom")+
  labs(caption="Indiana County Openness Group", fill="", color="")+
  theme(plot.caption = element_text(size=22, hjust = 0.5))


group_map_in+  theme(legend.key.size = unit(1, 'cm'), 
                     legend.key.height = unit(1, 'cm'), 
                     legend.key.width = unit(1, 'cm'), 
                     legend.title = element_text(size=22), 
                     legend.text = element_text(size=22)) 

dev.copy(pdf,'figure-4b.pdf')
dev.off()


