
** School Enrollment data

clear
set more off, perm

gl school "schools/rawdata_schools"
gl output "schools/cleaned_schools"
       
********************************************************************************
** 1) NCES data to keep elementary schools
********************************************************************************

import delimited "$school/nces_data.csv", varnames(6) clear

ren(stateabbrpublicschoollatestavail schoolidncesassignedpublicschool lowestgradeofferedpublicschool20 highestgradeofferedpublicschool2) ///
   (state ncessch low_grade high_grade)
replace ncessch = subinstr(ncessch,`"=""',"",.)
replace ncessch = subinstr(ncessch,`"""',"",.)

destring ncessch, replace
drop if low_grade == "Adult Education" | low_grade == "Ungraded" | high_grade == "Adult Education" | high_grade == "Ungraded"
foreach var in low_grade high_grade {
   replace `var' = subinstr(`var',"th Grade","",.)
   replace `var' = subinstr(`var',"nd Grade","",.)
   replace `var' = subinstr(`var',"rd Grade","",.)
   replace `var' = subinstr(`var',"st Grade","",.)
   replace `var' = subinstr(`var',"†","",.)
   replace `var' = subinstr(`var',"–","",.)
   replace `var' = subinstr(`var',"Prekindergarten","-1",.)
   replace `var' = subinstr(`var',"Kindergarten","0",.)
   destring `var', replace
}

// Keep elementary schools
keep if high_grade <= 5
gen nces_keep = 1
keep ncessch nces_keep

tempfile nces
save `nces', replace

********************************************************************************
** 2) Enrollment data
********************************************************************************

// School data
use "$school/CSDH_schools_appended_data_for_analysis.dta", clear
rename *, lower
ren (stateabbrev ncesschoolid) (state ncessch)

foreach var in periodstartdate periodenddate {
   format `var' %td
}
drop if learningmodel == ""
tab learningmodel, gen(D)
ren (D1 D2 D3 D4) (closed hybrid in_person virtual)

drop if charter == "Yes"

merge m:1 ncessch using `nces', nogen keep(match)

// Keep if fall of 2020
keep if periodstartdate>=td(01sep2020) & periodenddate <= td(30nov2020)

collapse (mean) enrollmenttotal hybrid in_person virtual (first) state, by(ncessch)

collapse (mean) hybrid in_person virtual, by(state)
save "$output/state_enrollment_percent.dta", replace

********************************************************************************
** 3) District Data - K5 learning mode
********************************************************************************

use "$school/CSDH_districts_appended_data_for_analysis.dta", clear
rename *, lower
ren stateabbrev state

foreach var in periodstartdate periodenddate {
   format `var' %td
}
drop if learningmodelgrk5 == ""
tab learningmodelgrk5, gen(D)
ren (D1 D2 D3 D4) (closed hybrid in_person virtual)

drop if charter == "Yes"

// Keep if fall of 2020
keep if periodstartdate>=td(01sep2020) & periodenddate <= td(30nov2020)

collapse (mean) enrollmenttotal hybrid in_person virtual (first) state, by(ncesdistrictid)

collapse (mean) hybrid in_person virtual, by(state)
save "$output/state_enrollment_k5district_percent.dta", replace

********************************************************************************
** 4) District Data - All learning modes
********************************************************************************

use "$school/CSDH_districts_appended_data_for_analysis.dta", clear
rename *, lower
ren stateabbrev state

foreach var in periodstartdate periodenddate {
   format `var' %td
}

drop if learningmodel == ""
replace learningmodel = "In-Person" if learningmodel == "In-person"
tab learningmodel, gen(D)
ren (D1 D2 D3 D4) (closed hybrid in_person virtual)

drop if charter == "Yes"

// Keep if fall of 2020
keep if periodstartdate>=td(01sep2020) & periodenddate <= td(30nov2020)
collapse (mean) enrollmenttotal hybrid in_person virtual (first) state, by(ncesdistrictid)

collapse (mean) hybrid in_person virtual, by(state)
save "$output/state_enrollment_alldistrict_percent.dta", replace

********************************************************************************
** 5) Indiana Schools - Enrollment data
********************************************************************************

// Schools data
use "$school/CSDH_schools_appended_data_for_analysis.dta", clear
rename *, lower
ren (stateabbrev ncesschoolid) (state ncessch)

keep if state == "IN"

foreach var in periodstartdate periodenddate {
   format `var' %td
}
drop if learningmodel == ""
tab learningmodel, gen(D)
ren (D1 D2 D3 D4) (closed hybrid in_person virtual)

drop if charter == "Yes"

// Keep if fall of 2020
keep if periodstartdate>=td(01sep2020) & periodenddate <= td(30nov2020)
collapse (mean) hybrid in_person virtual, by(ncessch)
save "$output/indiana_oster_enrollment.dta", replace
